@@ -4,12 +4,10 @@ Resources:
   - http://huygens-fokker.org/docs/intervals.html
 """
 import fractions
-import os
+import pkgutil
 
-from klang.config import INTERVALS_FILEPATH
-from klang import ROOT_DIR
 from klang.util import find_item
-from klang.util import load_music_data_from_csv
+from klang.util import parse_music_data_from_csv
 
 
 INTERVALS = {}
@@ -21,15 +19,15 @@ def find_interval(name):
     return find_item(INTERVALS, name)
 
 
-def _load_intervals_from_csv(filepath):
+def _load_intervals():
     """Load intervals from CSV file."""
+    data = pkgutil.get_data('klang.music', 'data/intervals.csv')
     intervals = {
         name: fractions.Fraction(ratio[0])
-        for name, ratio in load_music_data_from_csv(filepath).items()
+        for name, ratio in parse_music_data_from_csv(data).items()
     }
+
     return intervals
 
 
-INTERVALS = _load_intervals_from_csv(
-    os.path.join(ROOT_DIR, INTERVALS_FILEPATH)
-)
+INTERVALS = _load_intervals()
