@@ -5,14 +5,13 @@ Conversion functions, temperaments.
 Resources:
   - http://www.wolfgang-wiese.de/Historische%20Stimmungen-Schwebungen.pdf.
 """
-import os
+import pkgutil
 
 import numpy as np
 
-from klang.config import KAMMERTON, TUNINGS_FILEPATH
-from klang import ROOT_DIR
+from klang.config import KAMMERTON
 from klang.constants import DODE, REF_OCTAVE, CENT_PER_OCTAVE
-from klang.util import load_music_data_from_csv, find_item
+from klang.util import parse_music_data_from_csv, find_item
 
 
 TEMPERAMENTS = {}
@@ -75,7 +74,7 @@ class Temperament:
         return '%s(%s)' % (type(self).__name__, ', '.join(infos))
 
 
-def _init_temperaments(filepath=None):
+def _init_temperaments():
     youngRatios = [
         1., 1.055730636, 1.119771437, 1.187696971, 1.253888072, 1.334745462,
         1.407640848, 1.496510232, 1.583595961, 1.675749414, 1.781545449,
@@ -96,13 +95,14 @@ def _init_temperaments(filepath=None):
         'Random': Temperament(rnd, name='Random'),
     }
 
-    if filepath is not None:
-        for name, cents in load_music_data_from_csv(filepath).items():
-            temperaments[name.title().strip()] = Temperament(cents, name=name)
+    # Load remaing temperaments from tunings.csv
+    data = pkgutil.get_data('klang.music', 'data/tunings.csv')
+    for name, cents in parse_music_data_from_csv(data).items():
+        temperaments[name.title().strip()] = Temperament(cents, name=name)
 
     return temperaments
 
 
 EQUAL_TEMPERAMENT = Temperament(np.arange(DODE)*100, kammerton=KAMMERTON, name='Equal')
 TEMPERAMENTS['Equal'] = EQUAL_TEMPERAMENT
-TEMPERAMENTS.update(_init_temperaments(os.path.join(ROOT_DIR, TUNINGS_FILEPATH)))
+TEMPERAMENTS.update(_init_temperaments())
